<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Magpaper Pro
 * @since Magpaper Pro 1.0.0
 * @return array An array of default values
 */

function magpaper_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$magpaper_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#2a2e43',
		'header_tagline_color'			=> '#2a2e43',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#d67459',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite-version',
		// typography Options
		'theme_typography' 				=> '',
		'body_theme_typography' 		=> '',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// top bar
		'top_bar_enable'         		=> false,
		'top_bar_on'         			=> 'entire-site',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		'read_more_text'           		=> esc_html__( 'Continue Reading', 'magpaper-pro' ),
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'magpaper-pro' ), '[the-year]', '[site-link]' ),
		'powered_by_text'           	=> esc_html__( 'All Rights Reserved | ', 'magpaper-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'magpaper-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'magpaper-pro' ),
		'archive_image' 					=> get_template_directory_uri() . '/assets/uploads/header-image.jpg',
		'hide_date' 					=> false,
		'hide_category'					=> false,
		'hide_author'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// Header
		'header_section_enable'		=> true,
		'header_content_type'			=> 'post',

		// Header right
		'header_right_section_enable'		=> true,
		'header_right_content_type'			=> 'post',

		// Header
		'hero_section_enable'		=> true,
		'hero_content_type'			=> 'post',

		// Popular post
		'popular_post_title'			=> esc_html__( 'The Highlights', 'magpaper-pro' ),
		'popular_post_section_enable'	=> true,
		'popular_post_count'			=> 2,
		'popular_post_left_content_type'	=> 'post',
		'popular_post_right_content_type'	=> 'post',


		// blog
		'blog_section_title'			=> esc_html__( 'Latest Posts', 'magpaper-pro' ),
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'recent',
		'blog_count'					=> 4,
		'blog_section_btn_label'		=> esc_html__( 'Read More', 'magpaper-pro' ),


	);

	$output = apply_filters( 'magpaper_pro_default_theme_options', $magpaper_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}